@@ -18,8 +18,6 @@ class AirConditioner:
         self.__device = ac(ip_address, id, 6444)
         self.__datetime_last_refresh = datetime.now() - timedelta(days=1)
         self.__program_deactivation_time = None
-        self.__cooling_temp = 19
-        self.__heating_temp = 24
         self.__listeners = set()
         Thread(target=self.__run_refresh, daemon=True).start()
 
@@ -57,24 +55,6 @@ class AirConditioner:
         self.__device.apply()
         Thread(target=self.__sync, daemon=True).start()
 
-    def cooling_temp(self) -> int:
-        return int(round(self.__cooling_temp))
-
-    def set_cooling_temp(self, temp: int):
-        self.__cooling_temp = temp
-
-    def heating_temp(self) -> int:
-        return int(round(self.__heating_temp))
-
-    def set_heating_temp(self, temp: int):
-        self.__heating_temp = temp
-
-    def __remaining_operation_time_sec(self) -> int:
-        if self.__program_deactivation_time is None:
-            return 0
-        else:
-            return int(round((self.__program_deactivation_time - datetime.now()).total_seconds()))
-
     def power(self) -> bool:
         self.__sync(max_age_sec=3)
         return self.__device.power_state
@@ -87,7 +67,7 @@ class AirConditioner:
 
     def target_temperature(self) -> int:
         self.__sync(max_age_sec=3)
-        return int(round(self.__device.target_temperature))
+        return self.__device.target_temperature
 
     def set_target_temperature(self, target_temp: int):
         self.__device.target_temperature = target_temp
@@ -118,23 +98,56 @@ class AirConditioner:
         else:
             return "unknown (" + str(self.__device.operational_mode) + ")"
 
-    def __activate_program_until(self, end_date: datetime, target_temperature: float, operational_mode: int):
-        self.__program_deactivation_time = end_date
-        try:
-            self.__device.prompt_tone = True
-            self.__device.power_state = True
-            self.__device.target_temperature = target_temperature
-            self.__device.operational_mode = operational_mode
-            self.__apply()
-            logging.info("starting air conditioner (target temp: " + str(target_temperature) + "C, duration: " + str(round(self.__remaining_operation_time_sec())) + " sec)")
-        finally:
-            Thread(target=self.__program_deactivation_watchdog, daemon=True).start()
+    def set_operational_mode(self, mode: str):
+        if mode == 'cool':
+            self.__device.operational_mode  = ac.operational_mode_enum.cool
+        elif mode == 'heat':
+            self.__device.operational_mode  = ac.operational_mode_enum.heat
+        elif mode == 'auto':
+            self.__device.operational_mode  = ac.operational_mode_enum.auto
+        elif mode == 'dry':
+            self.__device.operational_mode  = ac.operational_mode_enum.dry
+        else:
+            logging.warning("unknown mode " + mode + " to be set. igmoring it")
+            return
+        self.__apply()
+
+    def __remaining_program_time(self) -> float:
+        if self.__program_deactivation_time is None:
+            return 0
+        else:
+            remaining_sec = (self.__program_deactivation_time - datetime.now()).total_seconds()
+            if remaining_sec < 0:
+                return 0
+            else:
+                return remaining_sec
+
+    def run_util(self) -> str:
+        time = self.__program_deactivation_time
+        if time is None:
+            return ""
+        else:
+            return time.strftime("%Y.%m.%dT%H:%M:%S")
+
+    def set_run_util(self, end_date: str):
+        time = datetime.strptime(end_date, "%Y.%m.%dT%H:%M:%S")
+        if time > datetime.now():
+            self.__program_deactivation_time = time
+            try:
+                self.__device.prompt_tone = True
+                self.__device.power_state = True
+                self.__apply()
+                logging.info("starting air conditioner (mode: " + str(self.__device.operational_mode) + " target temp: " + str(self.__device.target_temperature) + "C, duration: " + str(self.__remaining_program_time()) + " sec)")
+            finally:
+                Thread(target=self.__program_deactivation_watchdog, daemon=True).start()
+        else:
+            raise Exception(end_date + " is in the past. Will be ignored")
 
     def __program_deactivation_watchdog(self):
         time.sleep(5)
         self.__sync()
         if self.__program_deactivation_time is not None:
-            time.sleep(self.__remaining_operation_time_sec())
+            time.sleep(self.__remaining_program_time())
             logging.info("program completed. Stopping device")
             self.set_power(False)
 
@@ -146,24 +159,6 @@ class AirConditioner:
                 sleep(60)
                 Thread(target=self.__program_deactivation_watchdog, daemon=True).start()
 
-    def cooling_remaining_minutes(self) -> int:
-        if self.__device.operational_mode == ac.operational_mode_enum.cool:
-            return int(round(self.__remaining_operation_time_sec() / 60, 1))
-        else:
-            return 0
-
-    def set_cooling_remaining_minutes(self, duration: int):
-        self.__activate_program_until(datetime.now() + timedelta(minutes=duration), self.__cooling_temp, ac.operational_mode_enum.cool)
-
-    def heating_remaining_minutes(self) -> int:
-        if self.__device.operational_mode == ac.operational_mode_enum.heat:
-            return int(round(self.__remaining_operation_time_sec() / 60, 1))
-        else:
-            return 0
-
-    def set_heating_remaining_minutes(self, duration: int):
-        self.__activate_program_until(datetime.now() + timedelta(minutes=duration), self.__heating_temp, ac.operational_mode_enum.heat)
-
     def __str__(self):
         self.__sync()
         return json.dumps({
